@@ -2,12 +2,12 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA     = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.010';
+our $VERSION = '1.011';
 
 use CPAN;
 no warnings 'redefine';
 local *CPAN::Shell::myprint = sub { };
-CPAN::HandleConfig->load;
+eval { CPAN::HandleConfig->load; };
 
 __PACKAGE__->init(
     $INC{'CPAN/MyConfig.pm'} || $INC{'CPAN/Config.pm'}
@@ -29,7 +29,8 @@ Acme::MetaSyntactic::pause_id - The PAUSE id theme
 This is the list of all PAUSE (Perl Authors Upload SErver) user id
 (slightly transmogrified to be valid Perl identifiers).
 
-This list seems to require frequent updates. C<;-)>
+This list used to require frequent updates, until the data was read from
+L<CPAN> local configuration. C<;-)>
 
 =head1 CONTRIBUTOR
 
@@ -41,6 +42,13 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2013-01-14 - v1.011
+
+Made more resistant to L<CPAN> errors.
+Published in Acme-MetaSyntactic-Themes version 1.029.
+
+=item *
+
 2012-11-12 - v1.010
 
 Updated to use CPAN.pm to obtain the list of PAUSE ID. If CPAN.pm is
